@@ -625,7 +625,7 @@ def delayed(obj, name=None, pure=None, nout=None, traverse=True):
         collections = set()
 
     if not (nout is None or (type(nout) is int and nout >= 0)):
-        raise ValueError("nout must be None or a non-negative integer, got %s" % nout)
+        raise ValueError(f"nout must be None or a non-negative integer, got {nout}")
     if task is obj:
         if isinstance(obj, TaskRef):
             name = obj.key
@@ -732,7 +732,7 @@ class Delayed(DaskMethodsMixin, OperatorMethodMixin):
         return Delayed(key, dsk, self._length, layer=layer)
 
     def __repr__(self):
-        return f"Delayed({repr(self.key)})"
+        return f"Delayed({self.key!r})"
 
     def __hash__(self):
         return hash(self.key)
@@ -808,10 +808,7 @@ def call_function(func, func_token, args, kwargs, pure=None, nout=None):
     pure = kwargs.pop("pure", pure)
 
     if dask_key_name is None:
-        name = "{}-{}".format(
-            funcname(func),
-            tokenize(func_token, *args, pure=pure, **kwargs),
-        )
+        name = f"{funcname(func)}-{tokenize(func_token, *args, pure=pure, **kwargs)}"
     else:
         name = dask_key_name
 
@@ -868,7 +865,7 @@ class DelayedAttr(Delayed):
     __slots__ = ("_obj", "_attr")
 
     def __init__(self, obj, attr):
-        key = "getattr-%s" % tokenize(obj, attr, pure=True)
+        key = f"getattr-{tokenize(obj, attr, pure=True)}"
         super().__init__(key, None)
         self._obj = obj
         self._attr = attr
