@@ -11,12 +11,9 @@ import weakref
 from functools import partial
 from operator import add
 
-from packaging.version import Version
-
 from distributed import Client, SchedulerPlugin, futures_of, wait
-from distributed.utils_test import cleanup  # noqa: F401
-from distributed.utils_test import client as c  # noqa: F401
 from distributed.utils_test import (  # noqa: F401
+    cleanup,
     cluster,
     cluster_fixture,
     gen_cluster,
@@ -26,6 +23,8 @@ from distributed.utils_test import (  # noqa: F401
     s,
     varying,
 )
+from distributed.utils_test import client as c  # noqa: F401
+from packaging.version import Version
 
 import dask
 import dask.bag as db
